@@ -210,7 +210,7 @@ class DecoParam:
 from typing import Optional
 import re
 
-token_p = re.compile('\w+')
+token_p = re.compile(r'\w+')
 
 
 # TODO: Research how to keep the params in the order they were declared.
